summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authormallum <mallum@b067294f-1dea-0310-9683-c47a78595994>2005-01-12 19:36:45 +0000
committermallum <mallum@b067294f-1dea-0310-9683-c47a78595994>2005-01-12 19:36:45 +0000
commit5ab2b0e510663f14c9dc8e2e6541e7f0c0373d66 (patch)
treeb6d507170e9f330c35466c891dbe8929ea2b00bf
parent886ecf00f01de5b69477cae333215f5f928c9ae2 (diff)
Boring rename
git-svn-id: http://svn.o-hand.com/repos/matchbox/trunk/Xoo@1030 b067294f-1dea-0310-9683-c47a78595994
-rw-r--r--ChangeLog18
-rw-r--r--README4
-rw-r--r--configure.ac2
-rw-r--r--data/Makefile.am4
-rw-r--r--data/Xoo.glade (renamed from data/matchbox-nest.glade)6
-rw-r--r--src/Makefile.am6
-rw-r--r--src/button.c4
-rw-r--r--src/callbacks.c4
-rw-r--r--src/config.c4
-rw-r--r--src/fakedev.h4
-rw-r--r--src/keys.c4
-rw-r--r--src/main.c8
-rw-r--r--src/prefs.c4
-rw-r--r--src/prefs.h6
14 files changed, 48 insertions, 30 deletions
diff --git a/ChangeLog b/ChangeLog
index d54e096..d816fa4 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,21 @@
+2005-01-12 mallum,,, <mallum@openedhand.com>
+
+ * README:
+ * configure.ac:
+ * data/Makefile.am:
+ * data/Xoo.glade:
+ * data/matchbox-nest.glade:
+ * src/Makefile.am:
+ * src/button.c:
+ * src/callbacks.c:
+ * src/config.c:
+ * src/fakedev.h:
+ * src/keys.c:
+ * src/main.c: (fakeapp_new):
+ * src/prefs.c:
+ * src/prefs.h:
+ Rename matchbox-nest -> Xoo
+
2004-12-03 mallum,,, <mallum@openedhand.com>
* Makefile.am:
diff --git a/README b/README
index 4574c70..6cc75b7 100644
--- a/README
+++ b/README
@@ -1,7 +1,7 @@
-matchbox-nest ReadMe.
+Xoo ReadMe.
======================
-Matchbox-nest is a graphical wrapper around xnest. You can make Xnest
+Xoo is a graphical wrapper around xnest. You can make Xnest
look like a particular device's display and set up buttons on that
device.
diff --git a/configure.ac b/configure.ac
index 7b8eea8..38a69ac 100644
--- a/configure.ac
+++ b/configure.ac
@@ -2,7 +2,7 @@
# Process this file with autoconf to produce a configure script.
AC_PREREQ(2.53)
-AC_INIT([matchbox-nest], 0.5, [mallum@handhelds.org])
+AC_INIT([Xoo], 0.5, [mallum@handhelds.org])
AC_CONFIG_SRCDIR([src/main.c])
AM_INIT_AUTOMAKE()
diff --git a/data/Makefile.am b/data/Makefile.am
index cb863f6..d158b1b 100644
--- a/data/Makefile.am
+++ b/data/Makefile.am
@@ -1,8 +1,8 @@
-EXTRA_DIST = ipaq3800.xml ipaq3800.png dot.png matchbox-nest.glade
+EXTRA_DIST = ipaq3800.xml ipaq3800.png dot.png Xoo.glade
devicedir = $(pkgdatadir)
device_DATA = ipaq3800.xml ipaq3800.png dot.png
uidir = $(pkgdatadir)
-ui_DATA = matchbox-nest.glade
+ui_DATA = Xoo.glade
diff --git a/data/matchbox-nest.glade b/data/Xoo.glade
index 41b5553..a9f0b69 100644
--- a/data/matchbox-nest.glade
+++ b/data/Xoo.glade
@@ -7,7 +7,7 @@
<property name="can_focus">True</property>
<property name="has_focus">True</property>
<property name="events">GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK</property>
- <property name="title" translatable="yes">Matchbox-Nest</property>
+ <property name="title" translatable="yes">Xoo</property>
<property name="type">GTK_WINDOW_TOPLEVEL</property>
<property name="window_position">GTK_WIN_POS_NONE</property>
<property name="modal">False</property>
@@ -466,7 +466,7 @@
</widget>
<widget class="GtkWindow" id="aboutwindow">
- <property name="title" translatable="yes">Matchbox Nest</property>
+ <property name="title" translatable="yes">Xoo</property>
<property name="type">GTK_WINDOW_TOPLEVEL</property>
<property name="window_position">GTK_WIN_POS_NONE</property>
<property name="modal">False</property>
@@ -489,7 +489,7 @@
<child>
<widget class="GtkLabel" id="label6">
<property name="visible">True</property>
- <property name="label" translatable="yes">&lt;span size=&quot;xx-large&quot;&gt;&lt;b&gt;Matchbox Nest&lt;/b&gt;&lt;/span&gt;</property>
+ <property name="label" translatable="yes">&lt;span size=&quot;xx-large&quot;&gt;&lt;b&gt;Xoo&lt;/b&gt;&lt;/span&gt;</property>
<property name="use_underline">False</property>
<property name="use_markup">True</property>
<property name="justify">GTK_JUSTIFY_LEFT</property>
diff --git a/src/Makefile.am b/src/Makefile.am
index 3fffde1..2edee91 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,9 +1,9 @@
INCLUDES = -DPKGDATADIR=\"$(pkgdatadir)\" @APP_CFLAGS@ @EXPAT_CFLAGS@ @X_CFLAGS@ -Wall
-bin_PROGRAMS = matchbox-nest
+bin_PROGRAMS = Xoo
if HAVE_GCONF
GCONF_SOURCES = prefs.c prefs.h
endif
-matchbox_nest_SOURCES = main.c button.c callbacks.h callbacks.c config.c keys.c fakedev.h $(GCONF_SOURCES)
+Xoo_SOURCES = main.c button.c callbacks.h callbacks.c config.c keys.c fakedev.h $(GCONF_SOURCES)
-matchbox_nest_LDADD = @APP_LIBS@ @EXPAT_LIBS@ @X_LIBS@ @XTEST_LIBS@
+Xoo_LDADD = @APP_LIBS@ @EXPAT_LIBS@ @X_LIBS@ @XTEST_LIBS@
diff --git a/src/button.c b/src/button.c
index c95d69c..eeec5a1 100644
--- a/src/button.c
+++ b/src/button.c
@@ -1,6 +1,6 @@
-/* matchbox-nest - a graphical wrapper around xnest
+/* Xoo - a graphical wrapper around xnest
*
- * Copyright 2004 Matthew Allum
+ * Copyright 2004,2005 Matthew Allum, Openedhand Ltd <mallum@o-hand.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/callbacks.c b/src/callbacks.c
index 02ba81a..197fc17 100644
--- a/src/callbacks.c
+++ b/src/callbacks.c
@@ -1,6 +1,6 @@
-/* matchbox-nest - a graphical wrapper around xnest
+/* Xoo - a graphical wrapper around xnest
*
- * Copyright 2004 Matthew Allum
+ * Copyright 2004,2005 Matthew Allum, Openedhand Ltd <mallum@o-hand.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/config.c b/src/config.c
index 56cfb6b..71210b9 100644
--- a/src/config.c
+++ b/src/config.c
@@ -1,6 +1,6 @@
-/* matchbox-nest - a graphical wrapper around xnest
+/* Xoo - a graphical wrapper around xnest
*
- * Copyright 2004 Matthew Allum
+ * Copyright 2004,2005 Matthew Allum, Openedhand Ltd <mallum@o-hand.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/fakedev.h b/src/fakedev.h
index eec6037..845016c 100644
--- a/src/fakedev.h
+++ b/src/fakedev.h
@@ -1,6 +1,6 @@
-/* matchbox-nest - a graphical wrapper around xnest
+/* Xoo - a graphical wrapper around xnest
*
- * Copyright 2004 Matthew Allum
+ * Copyright 2004,2005 Matthew Allum, Openedhand Ltd <mallum@o-hand.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/keys.c b/src/keys.c
index d2a38ee..ae38e7c 100644
--- a/src/keys.c
+++ b/src/keys.c
@@ -1,6 +1,6 @@
-/* matchbox-nest - a graphical wrapper around xnest
+/* Xoo - a graphical wrapper around xnest
*
- * Copyright 2004 Matthew Allum
+ * Copyright 2004,2005 Matthew Allum, Openedhand Ltd <mallum@o-hand.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/prefs.c b/src/prefs.c
index 22009fa..22edad1 100644
--- a/src/prefs.c
+++ b/src/prefs.c
@@ -1,6 +1,6 @@
-/* matchbox-nest - a graphical wrapper around xnest
+/* Xoo - a graphical wrapper around xnest
*
- * Copyright 2004 Matthew Allum
+ * Copyright 2004,2005 Matthew Allum, Openedhand Ltd <mallum@o-hand.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/prefs.h b/src/prefs.h
index 8dd911d..c30305a 100644
--- a/src/prefs.h
+++ b/src/prefs.h
@@ -1,9 +1,9 @@
#include <gtk/gtkmenuitem.h>
#include "fakedev.h"
-#define GCONF_DISPLAY "/apps/matchbox-nest/display"
-#define GCONF_SERVER "/apps/matchbox-nest/xserver"
-#define GCONF_SERVER_OPTIONS "/apps/matchbox-nest/xserver-options"
+#define GCONF_DISPLAY "/apps/Xoo/display"
+#define GCONF_SERVER "/apps/Xoo/xserver"
+#define GCONF_SERVER_OPTIONS "/apps/Xoo/xserver-options"
void gconf_prefs_init(FakeApp *app);
diff --git a/src/main.c b/src/main.c
index 336fb1d..88e2310 100644
--- a/src/main.c
+++ b/src/main.c
@@ -1,6 +1,6 @@
/* matchbox-nest - a graphical wrapper around xnest
*
- * Copyright 2004 Matthew Allum
+ * Copyright 2004,2005 Matthew Allum, Openedhand Ltd <mallum@o-hand.com>
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -52,9 +52,9 @@ fakeapp_new(void)
app->key_rep_timeout.tv_usec = 40000;
app->key_rep_timeout.tv_sec = 0;
- app->win_title = "matchbox-nest";
+ app->win_title = "Xoo";
- glade = glade_xml_new (PKGDATADIR "/matchbox-nest.glade", NULL, NULL);
+ glade = glade_xml_new (PKGDATADIR "/Xoo.glade", NULL, NULL);
g_assert (glade != NULL);
glade_xml_signal_connect_data (glade, "on_send_signal_activate", (GCallback)on_send_signal_activate, app);
@@ -1,6 +1,6 @@
-/* matchbox-nest - a graphical wrapper around xnest
+/* Xoo - a graphical wrapper around xnest
*